OC.L10N.register(
    "deck",
    {
    "copy" : "copiar",
    "Done" : "Done",
    "Cancel" : "Anullar",
    "Details" : "Detalhs",
    "Sharing" : "Partiment",
    "Can edit" : "Can edit",
    "Can share" : "Can share",
    "Delete" : "Suprimir",
    "Edit" : "Modificar",
    "Title" : "Títol",
    "Description" : "Descripcion",
    "Save" : "Salvar",
    "Reply" : "Respondre",
    "Update" : "Metre a jorn",
    "seconds ago" : "i a qualques segondas",
    "Shared with you" : "Shared with you"
},
"nplurals=2; plural=(n > 1);");
